@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-from default import DefaultLocale
+from .default import DefaultLocale
 from dateutil.easter import easter
 from datetime import date, timedelta
 import calendar
 
+
 class SlovakLocale(DefaultLocale):
     @property
     def month_names(self):
@@ -19,15 +20,15 @@ class SlovakLocale(DefaultLocale):
             "September",
             "Október",
             "November",
-            "December"
+            "December",
         )
 
     @property
     def first_day_of_week(self):
-        return calendar.MONDAY   
-        
-    def holidays(self, year):
-        hols = super(SlovakLocale, self).holidays(year)
+        return calendar.MONDAY
+
+    def get_holidays(self, year):
+        hols = super().get_holidays(year)
         hols.append(date(year, 1, 1))
         hols.append(date(year, 1, 6))
         hols.append(date(year, 5, 1))
@@ -41,7 +42,11 @@ class SlovakLocale(DefaultLocale):
         hols.append(date(year, 12, 24))
         hols.append(date(year, 12, 25))
         hols.append(date(year, 12, 26))
-        
-        hols.append( easter(year) + timedelta(days=-2))
-        hols.append( easter(year) + timedelta(days=1))
-        return hols
\ No newline at end of file
+
+        hols.append(easter(year) + timedelta(days=-2))
+        hols.append(easter(year) + timedelta(days=1))
+        return hols
+
+    @property
+    def calendar_name(self):
+        return "Kalendár"
